@@ -35,7 +35,7 @@ LearnerClassifFeatureless = R6Class("LearnerClassifFeatureless", inherit = Learn
         feature_types = mlr_reflections$task_feature_types,
         predict_types = c("response", "prob"),
         param_set = ps,
-        properties = c("twoclass", "multiclass", "missings", "importance", "selected_features"),
+        properties = c("featureless", "twoclass", "multiclass", "missings", "importance", "selected_features"),
         man = "mlr3::mlr_learners_classif.featureless"
       )
     },
